==> okteta_15.12.3.orig.tar.xz: okteta-15.12.3/libs/kasten/core/tests/testdocumentfileconnectjob.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TESTDOCUMENTFILECONNECTJOB_H
#define TESTDOCUMENTFILECONNECTJOB_H

// Kasten core
#include <abstractfilesystemconnectjob.h>


namespace Kasten
{

class TestDocumentFileSynchronizer;
class TestDocument;
// class TestDocumentFileWriteThread;

class TestDocumentFileConnectJob : public AbstractFileSystemConnectJob
{
  Q_OBJECT

  public:
    TestDocumentFileConnectJob( TestDocumentFileSynchronizer* synchronizer, AbstractDocument* document,
                                const QUrl& url, AbstractModelSynchronizer::ConnectOption option );
    virtual ~TestDocumentFileConnectJob();

  protected: // AbstractFileSystemLoadJob API
    virtual void startConnectWithFile();

  protected Q_SLOTS:
//     void onDataPulled();

  protected:
//     TestDocumentFileWriteThread* mWriteThread;
};

}

#endif

==> okteta_17.12.3.orig.tar.xz: okteta-17.12.3/libs/kasten/core/tests/testdocumentfileconnectjob.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef TESTDOCUMENTFILECONNECTJOB_H
#define TESTDOCUMENTFILECONNECTJOB_H

// Kasten core
#include <abstractfilesystemconnectjob.h>


namespace Kasten
{

class TestDocumentFileSynchronizer;
class TestDocument;
// class TestDocumentFileWriteThread;

class TestDocumentFileConnectJob : public AbstractFileSystemConnectJob
{
  Q_OBJECT

  public:
    TestDocumentFileConnectJob( TestDocumentFileSynchronizer* synchronizer, AbstractDocument* document,
                                const QUrl& url, AbstractModelSynchronizer::ConnectOption option );
    ~TestDocumentFileConnectJob() override;

  protected: // AbstractFileSystemLoadJob API
    void startConnectWithFile() override;

  protected Q_SLOTS:
//     void onDataPulled();

  protected:
//     TestDocumentFileWriteThread* mWriteThread;
};

}

#endif
